==> freecad_0.21.2+dfsg1.orig.tar.xz: FreeCAD-0.21.2/src/Mod/Inspection/Gui/Resources/translations/Inspection_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja" sourcelanguage="en">
  <context>
    <name>CmdInspectElement</name>
    <message>
      <location filename="../../Command.cpp" line="74"/>
      <source>Inspection</source>
      <translation>検査</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <source>Inspection...</source>
      <translation>検査...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Get distance information</source>
      <translation>距離情報を取得</translation>
    </message>
  </context>
  <context>
    <name>CmdVisualInspection</name>
    <message>
      <location filename="../../Command.cpp" line="48"/>
      <source>Inspection</source>
      <translation>検査</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="49"/>
      <source>Visual inspection...</source>
      <translation>外観検査...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <location filename="../../Command.cpp" line="51"/>
      <source>Visual inspection</source>
      <translation>外観検査</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../VisualInspection.cpp" line="230"/>
      <source>Visual Inspection</source>
      <translation>外観検査</translation>
    </message>
  </context>
  <context>
    <name>InspectionGui::VisualInspection</name>
    <message>
      <location filename="../../VisualInspection.ui" line="14"/>
      <source>Visual Inspection</source>
      <translation>外観検査</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="23"/>
      <source>Actual</source>
      <translation type="unfinished">Actual</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="39"/>
      <location filename="../../VisualInspection.ui" line="66"/>
      <source>Objects</source>
      <translation>オブジェクト</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="50"/>
      <source>Nominal</source>
      <translation type="unfinished">Nominal</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="77"/>
      <source>Parameter</source>
      <translation>パラメーター</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="97"/>
      <source>Search distance</source>
      <translation type="unfinished">Search distance</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="129"/>
      <location filename="../../VisualInspection.ui" line="174"/>
      <source> mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="145"/>
      <source>Thickness</source>
      <translation>厚み</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="455"/>
      <source>Remove annotations</source>
      <translation>注釈を削除</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="456"/>
      <source>Do you want to remove all annotations?</source>
      <translation>すべての注釈を削除しますか?</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="508"/>
      <source>Annotation</source>
      <translation>注釈</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="511"/>
      <source>Leave info mode</source>
      <translation>情報モードを解除</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="632"/>
      <source>Distance: &gt; %1</source>
      <translation>距離: &gt; %1</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="635"/>
      <source>Distance: &lt; %1</source>
      <translation>距離: &lt; %1</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="654"/>
      <location filename="../../ViewProviderInspection.cpp" line="670"/>
      <source>Distance: %1</source>
      <translation>距離: %1</translation>
    </message>
  </context>
</TS>

==> freecad_1.0.0+dfsg.orig.tar.xz: FreeCAD-1.0.0/src/Mod/Inspection/Gui/Resources/translations/Inspection_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja" sourcelanguage="en">
  <context>
    <name>CmdInspectElement</name>
    <message>
      <location filename="../../Command.cpp" line="74"/>
      <source>Inspection</source>
      <translation>検査</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <source>Inspection...</source>
      <translation>ずれを計測...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Get distance information</source>
      <translation>ずれを計測</translation>
    </message>
  </context>
  <context>
    <name>CmdVisualInspection</name>
    <message>
      <location filename="../../Command.cpp" line="48"/>
      <source>Inspection</source>
      <translation>検査</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="49"/>
      <source>Visual inspection...</source>
      <translation>外観検査...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <location filename="../../Command.cpp" line="51"/>
      <source>Visual inspection</source>
      <translation>外観検査</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../VisualInspection.cpp" line="237"/>
      <source>Visual Inspection</source>
      <translation>外観検査</translation>
    </message>
  </context>
  <context>
    <name>InspectionGui::VisualInspection</name>
    <message>
      <location filename="../../VisualInspection.ui" line="14"/>
      <source>Visual Inspection</source>
      <translation>外観検査</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="23"/>
      <source>Actual</source>
      <translation>比較元</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="39"/>
      <location filename="../../VisualInspection.ui" line="66"/>
      <source>Objects</source>
      <translation>オブジェクト</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="50"/>
      <source>Nominal</source>
      <translation>比較先</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="77"/>
      <source>Parameter</source>
      <translation>パラメーター</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="97"/>
      <source>Search distance</source>
      <translation>検出するずれの大きさの下限値</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="129"/>
      <location filename="../../VisualInspection.ui" line="174"/>
      <source> mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="145"/>
      <source>Thickness</source>
      <translation>厚さ</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="489"/>
      <source>Remove annotations</source>
      <translation>画面上の計測値を削除する</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="490"/>
      <source>Do you want to remove all annotations?</source>
      <translation>画面上の全ての計測値を削除しますか？</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="548"/>
      <source>Annotation</source>
      <translation>計測値を画面上に記録する</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="551"/>
      <source>Leave info mode</source>
      <translation>計測値を画面上に記録しない</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="682"/>
      <source>Distance: &gt; %1</source>
      <translation>ずれ： &gt; %1</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="686"/>
      <source>Distance: &lt; %1</source>
      <translation>ずれ： &lt; %1</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="706"/>
      <location filename="../../ViewProviderInspection.cpp" line="723"/>
      <source>Distance: %1</source>
      <translation>ずれ： %1</translation>
    </message>
  </context>
</TS>
